@@ -3,7 +3,7 @@ BEGIN {
   $App::Pocoirc::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $App::Pocoirc::VERSION = '0.07';
+  $App::Pocoirc::VERSION = '0.08';
 }
 
 use strict;
@@ -316,14 +316,14 @@ sub _status {
     $context = $self->_irc_to_network($context) if $irc;
     $context = defined $context ? " [$context]" : '';
     
-    $message = "$stamp$context $message\n";
+    $message = "$stamp$context $message";
 
     if (!$self->{daemonize}) {
         if ($error) {
-            print colored($message, 'red');
+            print colored($message, 'red'), "\n";
         }
         else {
-            print colored($message, 'green');
+            print colored($message, 'green'), "\n";
         }
     }
 
@@ -334,7 +334,7 @@ sub _status {
         }
 
         $fh->autoflush(1);
-        print $fh $message;
+        print $fh $message, "\n";
         close $fh;
     }
 
